@@ -1,6 +1,5 @@
 /*
-    <one line to give the library's name and an idea of what it does.>
-    Copyright (C) 2011  Shantanu Tushar shaan7in@gmail.com
+    Copyright (C) 2011  Shantanu Tushar shantanu@kde.org
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -37,7 +36,7 @@ private slots:
 
 private:
     VideoThumbnailProvider *m_thumbProvider;
-    mutable QHash<QString, QModelIndex> m_pendingThumbs;        //aw mutable, any other way to let data() change this?
+    mutable QHash<QString, QPersistentModelIndex> m_pendingThumbs;        //aw mutable, any other way to let data() change this?
 };
 
 #endif // LOCALVIDEOSMODEL_H
